netapp_ontap.models.software_package_download_get API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.software_package_download_get`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SoftwarePackageDownloadGetSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SoftwarePackageDownloadGet object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `code: Size GET`

    Code returned corresponds to a download message

    Example: 10551382

  `message: str GET`

    Download progress details

    Example: Package download in progress

  `state: str GET`

    Download status of the package

    Valid choices:

    - not_started
    - running
    - success
    - failure